import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { DmsBaseLubeStandardVO, DmsBaseLubeStandardForm, DmsBaseLubeStandardQuery } from '@/api/dms/dmsBaseLubeStandard/types';

/**
 * 查询润滑标准信息列表
 * @param query
 * @returns {*}
 */

export const listDmsBaseLubeStandard = (query?: DmsBaseLubeStandardQuery): AxiosPromise<DmsBaseLubeStandardVO[]> => {
  return request({
    url: '/dms/dmsBaseLubeStandard/list',
    method: 'get',
    params: query
  });
};

/**
 * 查询润滑标准信息详细
 * @param lubeStandardId
 */
export const getDmsBaseLubeStandard = (lubeStandardId: string | number): AxiosPromise<DmsBaseLubeStandardVO> => {
  return request({
    url: '/dms/dmsBaseLubeStandard/' + lubeStandardId,
    method: 'get'
  });
};

/**
 * 新增润滑标准信息
 * @param data
 */
export const addDmsBaseLubeStandard = (data: DmsBaseLubeStandardForm) => {
  return request({
    url: '/dms/dmsBaseLubeStandard',
    method: 'post',
    data: data
  });
};

/**
 * 修改润滑标准信息
 * @param data
 */
export const updateDmsBaseLubeStandard = (data: DmsBaseLubeStandardForm) => {
  return request({
    url: '/dms/dmsBaseLubeStandard',
    method: 'put',
    data: data
  });
};

/**
 * 删除润滑标准信息
 * @param lubeStandardId
 */
export const delDmsBaseLubeStandard = (lubeStandardId: string | number | Array<string | number>) => {
  return request({
    url: '/dms/dmsBaseLubeStandard/' + lubeStandardId,
    method: 'delete'
  });
};


/**
 * 下拉框查询润滑标准信息列表
 * @param query
 * @returns {*}
 */
export function getDmsBaseLubeStandardList (query) {
    return request({
        url: '/dms/dmsBaseLubeStandard/getDmsBaseLubeStandardList',
        method: 'get',
        params: query
    });
};
