import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { DmsBaseLubeStationVO, DmsBaseLubeStationForm, DmsBaseLubeStationQuery } from '@/api/dms/dmsBaseLubeStation/types';

/**
 * 查询润滑部位信息列表
 * @param query
 * @returns {*}
 */

export const listDmsBaseLubeStation = (query?: DmsBaseLubeStationQuery): AxiosPromise<DmsBaseLubeStationVO[]> => {
  return request({
    url: '/dms/dmsBaseLubeStation/list',
    method: 'get',
    params: query
  });
};

/**
 * 查询润滑部位信息详细
 * @param lubeStationId
 */
export const getDmsBaseLubeStation = (lubeStationId: string | number): AxiosPromise<DmsBaseLubeStationVO> => {
  return request({
    url: '/dms/dmsBaseLubeStation/' + lubeStationId,
    method: 'get'
  });
};

/**
 * 新增润滑部位信息
 * @param data
 */
export const addDmsBaseLubeStation = (data: DmsBaseLubeStationForm) => {
  return request({
    url: '/dms/dmsBaseLubeStation',
    method: 'post',
    data: data
  });
};

/**
 * 修改润滑部位信息
 * @param data
 */
export const updateDmsBaseLubeStation = (data: DmsBaseLubeStationForm) => {
  return request({
    url: '/dms/dmsBaseLubeStation',
    method: 'put',
    data: data
  });
};

/**
 * 删除润滑部位信息
 * @param lubeStationId
 */
export const delDmsBaseLubeStation = (lubeStationId: string | number | Array<string | number>) => {
  return request({
    url: '/dms/dmsBaseLubeStation/' + lubeStationId,
    method: 'delete'
  });
};


/**
 * 下拉框查询润滑部位信息列表
 * @param query
 * @returns {*}
 */
export function getDmsBaseLubeStationList (query) {
    return request({
        url: '/dms/dmsBaseLubeStation/getDmsBaseLubeStationList',
        method: 'get',
        params: query
    });
};
